@@ -2,9 +2,7 @@
  * Copyright (c) 2010-2011, NORDUnet A/S */
 /* See LICENSE for licensing information. */
 
-#ifndef SYS_SOLARIS9
 #include <stdint.h>
-#endif
 
 #define DBG_DBG 8
 #define DBG_INFO 16
