@@ -1,9 +1,7 @@
 /* Copyright (c) 2008, UNINETT AS */
 /* See LICENSE for licensing information. */
 
-#ifndef SYS_SOLARIS9
 #include <stdint.h>
-#endif
 #include <pthread.h>
 
 struct hash {
