@@ -4,11 +4,7 @@
 #ifndef _LIST_H
 #define _LIST_H
 
-#ifdef SYS_SOLARIS9
-#include <sys/inttypes.h>
-#else
 #include <stdint.h>
-#endif
 
 struct list_node {
     struct list_node *next;
@@ -32,6 +28,9 @@ void list_free(struct list *list);
 /* appends entry to list; returns 1 if ok, 0 if malloc fails */
 int list_push(struct list *list, void *data);
 
+/* insert entry at front of the list; returns 1 if ok, 0 if malloc fails */
+int list_push_front(struct list *list, void *data);
+
 /* removes first entry from list and returns data */
 void *list_shift(struct list *list);
 
