@@ -3,9 +3,8 @@
 
 int radsecproxy_main(int argc, char **argv);
 
-int main(int argc, char **argv)
-{
-  return radsecproxy_main(argc, argv);
+int main(int argc, char **argv) {
+    return radsecproxy_main(argc, argv);
 }
 
 /* Local Variables: */
