@@ -58,7 +58,7 @@ struct radmsg *radmsg_init(uint8_t code, uint8_t id, uint8_t *auth) {
     if (auth)
         memcpy(msg->auth, auth, 16);
     else if (!RAND_bytes(msg->auth, 16)) {
-        free(msg);
+        radmsg_free(msg);
         return NULL;
     }
     return msg;
@@ -233,7 +233,7 @@ int radmsg2buf(struct radmsg *msg, uint8_t *secret, int secret_len, uint8_t **bu
     size = 20;
     for (node = list_first(msg->attrs); node; node = list_next(node))
         size += 2 + ((struct tlv *)node->data)->l;
-    if (size > 65535)
+    if (size > 65535 || size < 0)
         return -1;
     *buf = malloc(size);
     if (!*buf)
@@ -320,14 +320,15 @@ struct radmsg *buf2radmsg(uint8_t *buf, int len, uint8_t *secret, int secret_len
         }
 
         if (t == RAD_Attr_Message_Authenticator && secret) {
-            if (msg->code == RAD_Access_Accept || msg->code == RAD_Access_Reject || msg->code == RAD_Access_Challenge) {
+            if (msg->code == RAD_Access_Accept || msg->code == RAD_Access_Reject || msg->code == RAD_Access_Challenge ||
+                msg->code == RAD_Accounting_Response) {
                 if (rqauth)
                     memcpy(buf + 4, rqauth, 16);
                 else {
-                    debug(DBG_DBG, "buf2radmsg: unable to verify message authenticator, missing original access-request");
+                    debug(DBG_DBG, "buf2radmsg: unable to verify message authenticator, missing original request");
                     msg->msgauthinvalid = 1;
                 }
-            } else if (msg->code != RAD_Access_Request)
+            } else if (msg->code != RAD_Access_Request && msg->code != RAD_Status_Server)
                 debug(DBG_DBG, "buf2radmsg: unexpeted message-authnticator");
             if (l != 16 || !_checkmsgauth(buf, len, v, secret, secret_len)) {
                 debug(DBG_DBG, "buf2radmsg: message authenticator invalid");
@@ -403,11 +404,13 @@ int attrvalidate(unsigned char *attrs, int length) {
  * !NULL.  */
 struct tlv *makevendortlv(uint32_t vendor, struct tlv *attr) {
     struct tlv *newtlv = NULL;
-    uint8_t l, *v;
+    size_t l;
+    uint8_t *v;
 
-    if (!attr || attr->l > (RAD_Max_Attr_Value_Length - 6))
+    if (!attr)
+        return NULL;
+    if ((l = attr->l + 6) > RAD_Max_Attr_Value_Length)
         return NULL;
-    l = attr->l + 2 + 4;
     v = malloc(l);
     if (v) {
         vendor = htonl(vendor & 0x00ffffff); /* MSB=0 according to RFC 2865. */
