@@ -7,6 +7,7 @@
 #define _RADMSG_H
 
 #include "tlv11.h"
+#include <stdint.h>
 
 #define RAD_Min_Length 20
 #define RAD_Max_Length 4096
@@ -20,6 +21,12 @@
 #define RAD_Access_Challenge 11
 #define RAD_Status_Server 12
 #define RAD_Status_Client 13
+#define RAD_Disconnect_Request 40
+#define RAD_Disconnect_ACK 41
+#define RAD_Disconnect_NAK 42
+#define RAD_CoA_Request 43
+#define RAD_CoA_ACK 44
+#define RAD_CoA_NAK 45
 
 #define RAD_Attr_User_Name 1
 #define RAD_Attr_User_Password 2
@@ -42,8 +49,10 @@
 #define RAD_Attr_Event_Timestamp 55
 #define RAD_Attr_CHAP_Challenge 60
 #define RAD_Attr_Tunnel_Password 69
+#define RAD_Attr_EAP_Message 79
 #define RAD_Attr_Message_Authenticator 80
 #define RAD_Attr_CUI 89
+#define RAD_Attr_Error_Cause 101
 #define RAD_Attr_Operator_Name 126
 
 #define RAD_Acct_Status_Start 1
@@ -54,6 +63,7 @@
 #define RAD_Acct_Status_Accounting_Off 8
 #define RAD_Acct_Status_Failed 15
 
+#define RAD_Err_Unsupported_Extension 406
 
 #define RAD_VS_ATTR_MS_MPPE_Send_Key 16
 #define RAD_VS_ATTR_MS_MPPE_Recv_Key 17
@@ -63,6 +73,7 @@ struct radmsg {
     uint8_t id;
     uint8_t auth[20];
     struct list *attrs; /*struct tlv*/
+    uint8_t msgauthinvalid;
 };
 
 #define ATTRTYPE(x) ((x)[0])
@@ -73,7 +84,7 @@ struct radmsg {
 int get_checked_rad_length(uint8_t *buf);
 void radmsg_free(struct radmsg *);
 struct radmsg *radmsg_init(uint8_t, uint8_t, uint8_t *);
-int radmsg_add(struct radmsg *, struct tlv *);
+int radmsg_add(struct radmsg *, struct tlv *, uint8_t front);
 struct tlv *radmsg_gettype(struct radmsg *, uint8_t);
 struct list *radmsg_getalltype(const struct radmsg *msg, uint8_t type);
 int radmsg_copy_attrs(struct radmsg *dst,
@@ -87,6 +98,7 @@ int vattrname2val(char *attrname, uint32_t *vendor, uint32_t *type);
 int attrvalidate(unsigned char *attrs, int length);
 struct tlv *makevendortlv(uint32_t vendor, struct tlv *attr);
 int resizeattr(struct tlv *attr, uint8_t newlen);
+int verifyeapformat(struct radmsg *msg);
 
 /**
  * convert the attribute value to its string representation form the dictionary 
@@ -96,7 +108,7 @@ int resizeattr(struct tlv *attr, uint8_t newlen);
  * @return the string representation or NULL, if the attribute/value is not in the 
  * dictionary
  */
-const char* attrval2strdict(struct tlv *attr);
+const char *attrval2strdict(struct tlv *attr);
 
 #endif /*_RADMSG_H*/
 
