@@ -522,7 +522,7 @@ static int tlsaddcacrl(SSL_CTX *ctx, struct tls *conf) {
     calist = sk_X509_NAME_new_null();
     if (conf->cacertfile) {
         debug(DBG_DBG, "tlsaddcacrl: loading subject names from file %s", conf->cacertfile);
-        if (!SSL_add_file_cert_subjects_to_stack(calist, conf->certfile)) {
+        if (!SSL_add_file_cert_subjects_to_stack(calist, conf->cacertfile)) {
             while ((error = ERR_get_error()))
                 debug(DBG_ERR, "SSL: %s", ERR_error_string(error, NULL));
             debug(DBG_ERR, "tlsaddcacrl: failed to load CA subject names from file %s", conf->cacertfile);
@@ -725,13 +725,8 @@ static SSL_CTX *tlscreatectx(uint8_t type, struct tls *conf) {
     return ctx;
 }
 
-struct tls *tlsgettls(char *alt1, char *alt2) {
-    struct tls *t;
-
-    t = hash_read(tlsconfs, alt1, strlen(alt1));
-    if (!t && alt2)
-        t = hash_read(tlsconfs, alt2, strlen(alt2));
-    return t;
+struct tls *tlsgettls(char *conf) {
+    return hash_read(tlsconfs, conf, strlen(conf));
 }
 
 struct tls *tlsgetdefaultpsk(void) {
@@ -974,7 +969,7 @@ static int matchsubjaltname(X509 *cert, struct certattrmatch *match) {
     }
 
     if (r < 1)
-        debug(DBG_DBG, "matchsubjaltname: no matching Subject Alt Name found! (%s)", fail);
+        debug(DBG_DBG, "matchsubjaltname: no matching Subject Alt Name found! (%s)", fail ? fail : "no dNSName or URI entry");
     free(fail);
 
     GENERAL_NAMES_free(alt);
@@ -1897,6 +1892,8 @@ int reverifycert(SSL *ssl, SSL_CTX *ssl_ctx) {
         debug(result == 0 ? DBG_NOTICE : DBG_DBG, "reverify result: num=%d:%s:depth=%d:%s", X509_STORE_CTX_get_error(ctx),
               X509_verify_cert_error_string(X509_STORE_CTX_get_error(ctx)),
               X509_STORE_CTX_get_error_depth(ctx), buf ? buf : "");
+        free(buf);
+        buf = NULL;
     }
 
     X509_STORE_CTX_free(ctx);
