@@ -3,54 +3,110 @@
  * Copyright (c) 2023, SWITCH */
 /* See LICENSE for licensing information. */
 
-#include <sys/socket.h>
+#include "util.h"
+#include "debug.h"
+#include <assert.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <netdb.h>
 #include <netinet/in.h>
 #include <netinet/tcp.h>
-#include <netdb.h>
+#include <poll.h>
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/socket.h>
 #include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <poll.h>
-#include <stdarg.h>
-#include <assert.h>
-#include "debug.h"
-#include "util.h"
 
 char *stringcopy(const char *s, int len) {
     char *r;
     if (!s)
-	return NULL;
+        return NULL;
     if (!len)
-	len = strlen(s);
+        len = strlen(s);
     r = malloc(len + 1);
     if (!r)
-	debugx(1, DBG_ERR, "stringcopy: malloc failed");
+        debugx(1, DBG_ERR, "stringcopy: malloc failed");
     memcpy(r, s, len);
     r[len] = '\0';
     return r;
 }
 
+/**
+ * @brief verify if str is properly utf-8 encoded
+ * 
+ * @param str string to verify
+ * @param str_len length of the string without terminating null.
+ * @return int 1 if valid utf-8, 0 otherwise
+ */
+int verifyutf8(const unsigned char *str, size_t str_len) {
+    const unsigned char *byte;
+    size_t charlen;
+
+    for (byte = str; byte < str + str_len; byte++) {
+        if (*byte == 0x00)
+            return 0;
+        if ((*byte & 0x80) == 0x00) {
+            if (*byte < 0x20 || *byte == 0x7F)
+                return 0;
+            continue;
+        }
+        if (*byte > 0xF4)
+            return 0;
+        if ((*byte & 0xE0) == 0xC0) {
+            if ((*byte & 0xFE) == 0xC0)
+                return 0;
+            charlen = 2;
+        } else if ((*byte & 0xF0) == 0xE0)
+            charlen = 3;
+        else if ((*byte & 0xF8) == 0xF0)
+            charlen = 4;
+        else
+            return 0;
+
+        if (byte + charlen - 1 >= str + str_len)
+            return 0;
+        if (charlen == 2 && *byte == 0xC2 && *(byte + 1) < 0xA0)
+            return 0;
+        if (charlen == 3) {
+            if (*byte == 0xE0 && (*(byte + 1) & 0xE0) == 0x80)
+                return 0;
+            if (*byte == 0xED && (*(byte + 1) & 0xE0) == 0xA0)
+                return 0;
+        }
+        if (charlen == 4) {
+            if (*byte == 0xF0 && (*(byte + 1) & 0xF0) == 0x80)
+                return 0;
+            if (*byte == 0xF4 && (*(byte + 1) & 0xF0) != 0x80)
+                return 0;
+        }
+
+        while (--charlen)
+            if ((*(++byte) & 0xC0) != 0x80)
+                return 0;
+    }
+    return 1;
+}
+
 void printfchars(char *prefixfmt, char *prefix, char *charfmt, uint8_t *chars, int len) {
     int i;
     unsigned char *s = (unsigned char *)chars;
     if (prefix)
-	printf(prefixfmt ? prefixfmt : "%s: ", prefix);
+        printf(prefixfmt ? prefixfmt : "%s: ", prefix);
     for (i = 0; i < len; i++)
-	printf(charfmt ? charfmt : "%c", s[i]);
+        printf(charfmt ? charfmt : "%c", s[i]);
     printf("\n");
 }
 
 void port_set(struct sockaddr *sa, uint16_t port) {
     switch (sa->sa_family) {
     case AF_INET:
-	((struct sockaddr_in *)sa)->sin_port = htons(port);
-	break;
+        ((struct sockaddr_in *)sa)->sin_port = htons(port);
+        break;
     case AF_INET6:
-	((struct sockaddr_in6 *)sa)->sin6_port = htons(port);
-	break;
+        ((struct sockaddr_in6 *)sa)->sin6_port = htons(port);
+        break;
     }
 }
 
@@ -59,17 +115,17 @@ struct sockaddr *addr_copy(struct sockaddr *in) {
 
     switch (in->sa_family) {
     case AF_INET:
-	out = malloc(sizeof(struct sockaddr_in));
+        out = malloc(sizeof(struct sockaddr_in));
         if (out == NULL)
             return NULL;
         *(struct sockaddr_in *)out = *(struct sockaddr_in *)in;
-	break;
+        break;
     case AF_INET6:
-	out = malloc(sizeof(struct sockaddr_in6));
+        out = malloc(sizeof(struct sockaddr_in6));
         if (out == NULL)
             return NULL;
         *(struct sockaddr_in6 *)out = *(struct sockaddr_in6 *)in;
-	break;
+        break;
     }
     assert(out);
 #ifdef SIN6_LEN
@@ -83,14 +139,14 @@ const char *addr2string(struct sockaddr *addr, char *buf, size_t len) {
     struct sockaddr_in sa4;
 
     if (addr->sa_family == AF_INET6) {
-	sa6 = (struct sockaddr_in6 *)addr;
-	if (IN6_IS_ADDR_V4MAPPED(&sa6->sin6_addr)) {
-	    memset(&sa4, 0, sizeof(sa4));
-	    sa4.sin_family = AF_INET;
-	    sa4.sin_port = sa6->sin6_port;
-	    memcpy(&sa4.sin_addr, &sa6->sin6_addr.s6_addr[12], 4);
-	    addr = (struct sockaddr *)&sa4;
-	}
+        sa6 = (struct sockaddr_in6 *)addr;
+        if (IN6_IS_ADDR_V4MAPPED(&sa6->sin6_addr)) {
+            memset(&sa4, 0, sizeof(sa4));
+            sa4.sin_family = AF_INET;
+            sa4.sin_port = sa6->sin6_port;
+            memcpy(&sa4.sin_addr, &sa6->sin6_addr.s6_addr[12], 4);
+            addr = (struct sockaddr *)&sa4;
+        }
     }
     if (getnameinfo(addr, SOCKADDRP_SIZE(addr), buf, len,
                     NULL, 0, NI_NUMERICHOST)) {
@@ -110,14 +166,14 @@ void disable_DF_bit(int socket, struct addrinfo *res) {
         /*
          * Turn off Path MTU discovery on IPv4/UDP sockets, Linux variant.
          */
-	int r, action;
+        int r, action;
         debug(DBG_INFO, "disable_DF_bit: disabling DF bit (Linux variant)");
         action = IP_PMTUDISC_DONT;
         r = setsockopt(socket, IPPROTO_IP, IP_MTU_DISCOVER, &action, sizeof(action));
         if (r == -1)
-	    debug(DBG_WARN, "Failed to set IP_MTU_DISCOVER");
+            debug(DBG_WARN, "Failed to set IP_MTU_DISCOVER");
 #else
-	debug(DBG_INFO, "Non-Linux platform, unable to unset DF bit for UDP. You should check with tcpdump whether radsecproxy will send its UDP packets with DF bit set!");
+        debug(DBG_INFO, "Non-Linux platform, unable to unset DF bit for UDP. You should check with tcpdump whether radsecproxy will send its UDP packets with DF bit set!");
 #endif
     }
 }
@@ -130,20 +186,20 @@ void enable_keepalive(int socket) {
     debug(DBG_NOTICE, "TCP Keepalive feature might be limited on this platform");
 #else
     optval = 3;
-    if(setsockopt(socket, IPPROTO_TCP, TCP_KEEPCNT, &optval, optlen) < 0) {
+    if (setsockopt(socket, IPPROTO_TCP, TCP_KEEPCNT, &optval, optlen) < 0) {
         debug(DBG_ERR, "enable_keepalive: setsockopt TCP_KEEPCNT failed");
     }
     optval = 10;
-    if(setsockopt(socket, IPPROTO_TCP, TCP_KEEPIDLE, &optval, optlen) < 0) {
+    if (setsockopt(socket, IPPROTO_TCP, TCP_KEEPIDLE, &optval, optlen) < 0) {
         debug(DBG_ERR, "enable_keepalive: setsockopt TCP_KEEPIDLE %d failed", optval);
     }
     optval = 10;
-    if(setsockopt(socket, IPPROTO_TCP, TCP_KEEPINTVL, &optval, optlen) < 0) {
+    if (setsockopt(socket, IPPROTO_TCP, TCP_KEEPINTVL, &optval, optlen) < 0) {
         debug(DBG_ERR, "enable_keepalive: setsockopt TCP_KEEPINTVL failed");
     }
 #endif
     optval = 1;
-    if(setsockopt(socket, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen) < 0) {
+    if (setsockopt(socket, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen) < 0) {
         debug(DBG_ERR, "enable_keepalive: setsockopt SO_KEEPALIVE failed");
     }
 }
@@ -161,7 +217,7 @@ int bindtoaddr(struct addrinfo *addrinfo, int family, int reuse) {
             continue;
         }
 
-        disable_DF_bit(s,res);
+        disable_DF_bit(s, res);
 
         if (reuse)
             if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) == -1)
@@ -194,27 +250,27 @@ int connectnonblocking(int s, const struct sockaddr *addr, socklen_t addrlen, in
         return -1;
     }
     if (!connect(s, addr, addrlen)) {
-	r = 0;
-	goto exit;
+        r = 0;
+        goto exit;
     }
     if (errno != EINPROGRESS)
-	goto exit;
+        goto exit;
 
     fds[0].fd = s;
     fds[0].events = POLLOUT;
     if (poll(fds, 1, timeout * 1000) < 1)
-	goto exit;
+        goto exit;
 
     if (fds[0].revents & POLLERR) {
-        if(!getsockopt(s, SOL_SOCKET, SO_ERROR, (void *)&sockerr, &errlen))
+        if (!getsockopt(s, SOL_SOCKET, SO_ERROR, (void *)&sockerr, &errlen))
             debug(DBG_WARN, "Connection failed: %s", strerror(sockerr));
         else
             debug(DBG_WARN, "Connection failed: unknown error");
     } else if (fds[0].revents & POLLHUP) {
-            debug(DBG_WARN, "Connect error: hang up");
+        debug(DBG_WARN, "Connect error: hang up");
     } else if (fds[0].revents & POLLNVAL) {
-            debug(DBG_WARN, "Connect error: fd not open");
-    } else if(fds[0].revents & POLLOUT) {
+        debug(DBG_WARN, "Connect error: fd not open");
+    } else if (fds[0].revents & POLLOUT) {
         debug(DBG_DBG, "Connection up");
         r = 0;
     }
@@ -231,27 +287,68 @@ int connecttcp(struct addrinfo *addrinfo, struct addrinfo *src, uint16_t timeout
 
     s = -1;
     if (timeout) {
-	if (addrinfo && addrinfo->ai_next && timeout > 5)
-	    timeout = 5;
+        if (addrinfo && addrinfo->ai_next && timeout > 5)
+            timeout = 5;
     }
 
     for (res = addrinfo; res; res = res->ai_next) {
-	s = bindtoaddr(src, res->ai_family, 1);
-	if (s < 0) {
-	    debug(DBG_WARN, "connecttoserver: socket failed");
-	    continue;
-	}
-	if ((timeout
-	     ? connectnonblocking(s, res->ai_addr, res->ai_addrlen, timeout)
-	     : connect(s, res->ai_addr, res->ai_addrlen)) == 0)
-	    break;
-	debug(DBG_WARN, "connecttoserver: connect failed");
-	close(s);
-	s = -1;
+        s = bindtoaddr(src, res->ai_family, 1);
+        if (s < 0) {
+            debug(DBG_WARN, "connecttoserver: socket failed");
+            continue;
+        }
+        if ((timeout
+                 ? connectnonblocking(s, res->ai_addr, res->ai_addrlen, timeout)
+                 : connect(s, res->ai_addr, res->ai_addrlen)) == 0)
+            break;
+        debug(DBG_WARN, "connecttoserver: connect failed");
+        close(s);
+        s = -1;
     }
     return s;
 }
 
+void accepttcp(int socket, void handler(int)) {
+    int s;
+    struct sockaddr_storage from;
+    socklen_t fromlen = sizeof(from);
+    char tmp[INET6_ADDRSTRLEN];
+
+    if (getsockname(socket, (struct sockaddr *)&from, &fromlen) != 0)
+        debugerrno(errno, DBG_ERR, "accepttcp: getsockname failed");
+    if (listen(socket, 128) != 0) {
+        debugerrno(errno, DBG_ERR, "accepttcp: listen on %s failed", addr2string((struct sockaddr *)&from, tmp, sizeof(tmp)));
+        goto exit;
+    }
+    debug(DBG_DBG, "accepttcp: listening on %s", addr2string((struct sockaddr *)&from, tmp, sizeof(tmp)));
+
+    for (;;) {
+        s = accept(socket, (struct sockaddr *)&from, &fromlen);
+        if (s < 0) {
+            switch (errno) {
+            case EBADF:
+            case EFAULT:
+            case EINVAL:
+            case ENOTSOCK:
+            case EOPNOTSUPP:
+            case EPERM:
+                /*non-recoverable errors, exit*/
+                debugerrno(errno, DBG_WARN, "accepttcp: accept failed, exiting");
+                goto exit;
+            case ECONNABORTED:
+                break;
+            default:
+                debugerrno(errno, DBG_WARN, "accepttcp: accept failed, trying again later");
+                sleep(1);
+            }
+            continue;
+        }
+        handler(s);
+    }
+exit:
+    close(socket);
+}
+
 uint32_t connect_wait(struct timeval attempt_start, struct timeval last_success, int firsttry) {
     struct timeval now;
 
